AGW Logo

svn SVN Revision 68881 For balloontip

This file contains the SVN revision history for balloontip, at revision 68881.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 20:51:43 UTC
  • Committer: AG
  • File Size: 32960 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • AGW: General overhaul of the documentation, much improved. All the widgets have their own sample usage in the docs as well;

  • FlatNotebook: Added the FNB_NAV_BUTTONS_WHEN_NEEDED style, which hides the navigation left/right arrows if all tabs fit;

  • RibbonBar: - Added the EVT_RIBBONBAR_TAB_LEFT_DCLICK event, which generates a special event

    when a ribbon bar tab is double-clicked;

    • Added support for toggle buttons;
    • Improved support for ribbon panel sizers: panels with sizers should now automatically minimise at small sizes, and behave properly when popping up from a minimised state;
    • Added tooltips via SetToolTip for those buttons which have the help_string attribute set.
  • XLSGrid: a new widget was added to AGW, termed XLSGrid. It’s based on wx.grid.Grid and can be used to faithfully reproduce the appearance of a Microsoft Excel spreadsheets.


svn_diff Diff To Previous Version (68742)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/balloontip.py 2011/08/16 16:37:37     68742
+++ wxPython/3rdParty/AGW/agw/balloontip.py 2011/08/25 16:40:17     68881
@@ -3,7 +3,7 @@
# Python Code By:
#
# Andrea Gavana, @ 29 May 2005
# Latest Revision: 11 Aug 2011, 23.00 GMT
#
#
# TODO List/Caveats
@@ -40,41 +40,41 @@
# --------------------------------------------------------------------------- #

"""
-BalloonTip is a class that allows you to display tooltips in a balloon style
+L{BalloonTip} is a class that allows you to display tooltips in a balloon style
window.


Description
===========

-BalloonTip is a class that allows you to display tooltips in a balloon style
+L{BalloonTip} is a class that allows you to display tooltips in a balloon style
window (actually a frame), similarly to the windows XP balloon help. There is
also an arrow that points to the center of the control designed as a "target"
-for the BalloonTip.
+for the L{BalloonTip}.

What it can do:

- Set the balloon shape as a rectangle or a rounded rectangle;
-- Set an icon to the top-left of the BalloonTip frame;
-- Set a title at the top of the BalloonTip frame;
-- Automatic "best" placement of BalloonTip frame depending on the target
+- Set an icon to the top-left of the L{BalloonTip} frame;
+- Set a title at the top of the L{BalloonTip} frame;
+- Automatic "best" placement of L{BalloonTip} frame depending on the target
control/window position;
- Runtime customization of title/tip fonts and foreground colours;
-- Runtime change of BalloonTip frame shape;
+- Runtime change of L{BalloonTip} frame shape;
- Set the balloon background colour;
-- Possibility to set the delay after which the BalloonTip is displayed;
-- Possibility to set the delay after which the BalloonTip is destroyed;
-- Three different behaviors for the BalloonTip window (regardless the delay
+- Possibility to set the delay after which the L{BalloonTip} is displayed;
+- Possibility to set the delay after which the L{BalloonTip} is destroyed;
+- Three different behaviors for the L{BalloonTip} window (regardless the delay
destruction time set):

-  a) Destroy by leave: the BalloonTip is destroyed when the mouse leaves the
+  a) Destroy by leave: the L{BalloonTip} is destroyed when the mouse leaves the
target control/window;
-  b) Destroy by click: the BalloonTip is destroyed when you click on any area
+  b) Destroy by click: the L{BalloonTip} is destroyed when you click on any area
of the target control/window;
-  c) Destroy by button: the BalloonTip is destroyed when you click on the
+  c) Destroy by button: the L{BalloonTip} is destroyed when you click on the
top-right close button;
-- Possibility to enable/disable globally the BalloonTip on you application;
-- Set the BalloonTip also for the taskbar icon.
+- Possibility to enable/disable globally the L{BalloonTip} on you application;
+- Set the L{BalloonTip} also for the taskbar icon.


Usage
@@ -97,10 +97,10 @@
mytextctrl = wx.TextCtrl(panel, -1, "I am a textctrl", pos=(100, 100))

# You can define your BalloonTip as follows:
-            tipballoon = BalloonTip(topicon=None, toptitle="textctrl",
-                                    message="this is a textctrl",
-                                    shape=BT.BT_ROUNDED,
-                                    tipstyle=BT.BT_LEAVE)
+            tipballoon = BT.BalloonTip(topicon=None, toptitle="textctrl",
+                                       message="this is a textctrl",
+                                       shape=BT.BT_ROUNDED,
+                                       tipstyle=BT.BT_LEAVE)

# Set the BalloonTip target
tipballoon.SetTarget(mytextctrl)
@@ -138,11 +138,11 @@
================ =========== ==================================================
Window Styles    Hex Value   Description
================ =========== ==================================================
-``BT_ROUNDED``           0x1 `BalloonTip` will have a rounded rectangular shape.
-``BT_RECTANGLE``         0x2 `BalloonTip` will have a rectangular shape.
-``BT_LEAVE``             0x3 `BalloonTip` will be destroyed when the user moves the mouse outside the target window.
-``BT_CLICK``             0x4 `BalloonTip` will be destroyed when the user click on `BalloonTip`.
-``BT_BUTTON``            0x5 `BalloonTip` will be destroyed when the user click on the close button.
+``BT_ROUNDED``           0x1 L{BalloonTip} will have a rounded rectangular shape.
+``BT_RECTANGLE``         0x2 L{BalloonTip} will have a rectangular shape.
+``BT_LEAVE``             0x3 L{BalloonTip} will be destroyed when the user moves the mouse outside the target window.
+``BT_CLICK``             0x4 L{BalloonTip} will be destroyed when the user click on L{BalloonTip}.
+``BT_BUTTON``            0x5 L{BalloonTip} will be destroyed when the user click on the close button.
================ =========== ==================================================


@@ -157,7 +157,7 @@

BalloonTip is distributed under the wxPython license.

-Latest revision: Andrea Gavana @ 11 Aug 2011, 23.00 GMT
+Latest revision: Andrea Gavana @ 17 Aug 2011, 15.00 GMT

Version 0.2

@@ -170,17 +170,17 @@

# Define The Values For The BalloonTip Frame Shape
BT_ROUNDED = 1
-""" `BalloonTip` will have a rounded rectangular shape. """
+""" L{BalloonTip} will have a rounded rectangular shape. """
BT_RECTANGLE = 2
-""" `BalloonTip` will have a rectangular shape. """
+""" L{BalloonTip} will have a rectangular shape. """

# Define The Value For The BalloonTip Destruction Behavior
BT_LEAVE = 3
-""" `BalloonTip` will be destroyed when the user moves the mouse outside the target window. """
+""" L{BalloonTip} will be destroyed when the user moves the mouse outside the target window. """
BT_CLICK = 4
-""" `BalloonTip` will be destroyed when the user click on `BalloonTip`. """
+""" L{BalloonTip} will be destroyed when the user click on L{BalloonTip}. """
BT_BUTTON = 5
-""" `BalloonTip` will be destroyed when the user click on the close button. """
+""" L{BalloonTip} will be destroyed when the user click on the close button. """


# ---------------------------------------------------------------
@@ -510,8 +510,8 @@
======================= ========= ====================================
Shape Flag              Hex Value  Description
======================= ========= ====================================
-         ``BT_ROUNDED``           0x1      `BalloonTip` will have a rounded rectangular shape.
-         ``BT_RECTANGLE``         0x2      `BalloonTip` will have a rectangular shape.
+         ``BT_ROUNDED``           0x1      L{BalloonTip} will have a rounded rectangular shape.
+         ``BT_RECTANGLE``         0x2      L{BalloonTip} will have a rectangular shape.
======================= ========= ====================================

:param `tipstyle`: the L{BalloonTip} destruction behavior. It can be one of:
@@ -519,9 +519,9 @@
======================= ========= ====================================
Tip Flag                Hex Value  Description
======================= ========= ====================================
-         ``BT_LEAVE``                  0x3 `BalloonTip` will be destroyed when the user moves the mouse outside the target window.
-         ``BT_CLICK``                  0x4 `BalloonTip` will be destroyed when the user click on `BalloonTip`.
-         ``BT_BUTTON``                 0x5 `BalloonTip` will be destroyed when the user click on the close button.
+         ``BT_LEAVE``                  0x3 L{BalloonTip} will be destroyed when the user moves the mouse outside the target window.
+         ``BT_CLICK``                  0x4 L{BalloonTip} will be destroyed when the user click on L{BalloonTip}.
+         ``BT_BUTTON``                 0x5 L{BalloonTip} will be destroyed when the user click on the close button.
======================= ========= ====================================

"""
@@ -860,9 +860,9 @@
============== ========== =====================================
Tip Style      Hex Value  Description
============== ========== =====================================
-         ``BT_LEAVE``          0x3 `BalloonTip` will be destroyed when the user moves the mouse outside the target window.
-         ``BT_CLICK``          0x4 `BalloonTip` will be destroyed when the user click on `BalloonTip`.
-         ``BT_BUTTON``         0x5 `BalloonTip` will be destroyed when the user click on the close button.
+         ``BT_LEAVE``          0x3 L{BalloonTip} will be destroyed when the user moves the mouse outside the target window.
+         ``BT_CLICK``          0x4 L{BalloonTip} will be destroyed when the user click on L{BalloonTip}.
+         ``BT_BUTTON``         0x5 L{BalloonTip} will be destroyed when the user click on the close button.
============== ========== =====================================
"""
Tree
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 29 May 2005
-# Latest Revision: 11 Aug 2011, 23.00 GMT
+# Latest Revision: 17 Aug 2011, 15.00 GMT
#
#